@@ -12,7 +12,6 @@ from pathlib import Path
 from typing import (
     Optional,
     Self,
-    TypeVar,
 )
 
 import dacite
@@ -178,9 +177,6 @@ class ConfigBase:
         return config
 
 
-ConfigT = TypeVar('ConfigT', bound=ConfigBase)
-
-
 @dataclasses.dataclass
 class Config(ConfigBase):
     # Disable basic fields
@@ -251,9 +247,9 @@ class Config(ConfigBase):
         return config
 
     @classmethod
-    def _read_hierarchy(
-        cls, bases: Iterable[Path], orig: Iterable[ConfigT],
-    ) -> Iterable[ConfigT]:
+    def _read_hierarchy[T: ConfigBase](
+        cls, bases: Iterable[Path], orig: Iterable[T],
+    ) -> Iterable[T]:
         for i in orig:
             try:
                 assert i.path is not None
